Stan Math Library: stan/math/rev/mat.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mat.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/scal/meta/is_var.hpp>`
`#include <stan/math/rev/scal/meta/partials_type.hpp>`
`#include <stan/math/prim/mat.hpp>`
`#include <stan/math/rev/arr.hpp>`
`#include <stan/math/rev/mat/fun/cholesky_decompose.hpp>`
`#include <stan/math/rev/mat/fun/columns_dot_product.hpp>`
`#include <stan/math/rev/mat/fun/columns_dot_self.hpp>`
`#include <stan/math/rev/mat/fun/crossprod.hpp>`
`#include <stan/math/rev/mat/fun/determinant.hpp>`
`#include <stan/math/rev/mat/fun/divide.hpp>`
`#include <stan/math/rev/mat/fun/dot_product.hpp>`
`#include <stan/math/rev/mat/fun/dot_self.hpp>`
`#include <stan/math/rev/mat/fun/Eigen_NumTraits.hpp>`
`#include <stan/math/rev/mat/fun/grad.hpp>`
`#include <stan/math/rev/mat/fun/initialize_variable.hpp>`
`#include <stan/math/rev/mat/fun/LDLT_alloc.hpp>`
`#include <stan/math/rev/mat/fun/LDLT_factor.hpp>`
`#include <stan/math/rev/mat/fun/log_determinant.hpp>`
`#include <stan/math/rev/mat/fun/log_determinant_ldlt.hpp>`
`#include <stan/math/rev/mat/fun/log_determinant_spd.hpp>`
`#include <stan/math/rev/mat/fun/log_softmax.hpp>`
`#include <stan/math/rev/mat/fun/log_sum_exp.hpp>`
`#include <stan/math/rev/mat/fun/mdivide_left.hpp>`
`#include <stan/math/rev/mat/fun/mdivide_left_ldlt.hpp>`
`#include <stan/math/rev/mat/fun/mdivide_left_spd.hpp>`
`#include <stan/math/rev/mat/fun/mdivide_left_tri.hpp>`
`#include <stan/math/rev/mat/fun/multiply.hpp>`
`#include <stan/math/rev/mat/fun/multiply_lower_tri_self_transpose.hpp>`
`#include <stan/math/rev/mat/fun/quad_form.hpp>`
`#include <stan/math/rev/mat/fun/quad_form_sym.hpp>`
`#include <stan/math/rev/mat/fun/rows_dot_product.hpp>`
`#include <stan/math/rev/mat/fun/sd.hpp>`
`#include <stan/math/rev/mat/fun/softmax.hpp>`
`#include <stan/math/rev/mat/fun/sort_asc.hpp>`
`#include <stan/math/rev/mat/fun/sort_desc.hpp>`
`#include <stan/math/rev/mat/fun/squared_distance.hpp>`
`#include <stan/math/rev/mat/fun/stan_print.hpp>`
`#include <stan/math/rev/mat/fun/sum.hpp>`
`#include <stan/math/rev/mat/fun/tcrossprod.hpp>`
`#include <stan/math/rev/mat/fun/to_var.hpp>`
`#include <stan/math/rev/mat/fun/trace_gen_inv_quad_form_ldlt.hpp>`
`#include <stan/math/rev/mat/fun/trace_gen_quad_form.hpp>`
`#include <stan/math/rev/mat/fun/trace_inv_quad_form_ldlt.hpp>`
`#include <stan/math/rev/mat/fun/trace_quad_form.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/mat/fun/variance.hpp>`
`#include <stan/math/rev/mat/functor/gradient.hpp>`
`#include <stan/math/rev/mat/functor/jacobian.hpp>`
`#include <stan/math/rev/mat/functor/ode_system.hpp>`
`#include <stan/math/rev/mat/functor/cvodes_utils.hpp>`
`#include <stan/math/rev/mat/functor/cvodes_ode_data.hpp>`
`#include <stan/math/rev/mat/functor/integrate_ode_bdf.hpp>`

Go to the source code of this file.

[ Stan Home Page ] © 2011–2016, Stan Development Team.